'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var createRequest = require('./createRequest');

var successLog = function successLog(msg) {
  return console.log('[YOSGO-SDK Console ' + new Date().toISOString() + '] ' + msg);
};

var LINA = function () {
  function LINA(_ref) {
    var apiKey = _ref.apiKey,
        mode = _ref.mode;

    _classCallCheck(this, LINA);

    this.apiKey = apiKey;
    this.mode = mode;
  }

  _createClass(LINA, [{
    key: 'request',
    value: function request() {
      return createRequest({ apiKey: this.apiKey, mode: this.mode });
    }
  }, {
    key: 'getBrands',
    value: function getBrands() {
      var _this = this;

      return new Promise(function (resolve, reject) {
        _this.request().get('/brands').then(function (respones) {
          successLog('Fetch brands success');
          resolve(respones.data);
        });
      });
    }
  }, {
    key: 'getProducts',
    value: function getProducts() {
      var _this2 = this;

      var _ref2 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : { id: undefined },
          productId = _ref2.id;

      return new Promise(function (resolve, reject) {
        if (productId) {
          _this2.request().get('/products/' + productId + '/?forceUpdate=1').then(function (response) {
            successLog('Fetch certain product success');
            resolve(response.data.payload);
          });
        } else {
          _this2.request().get('/products').then(function (response) {
            successLog('Fetch products success');
            resolve(response.data.payload);
          });
        }
      });
    }
  }, {
    key: 'getGroups',
    value: function getGroups(isForceUpdate) {
      var _this3 = this;

      return new Promise(function (resolve, reject) {
        _this3.request().get('/groups/?forceUpdate=' + (isForceUpdate ? '1' : '0')).then(function (response) {
          successLog('Fetch groups success');
          resolve(response.data.payload);
        });
      });
    }
  }, {
    key: 'createGroup',
    value: function createGroup(_ref3) {
      var _this4 = this;

      var productId = _ref3.productId,
          _ref3$note = _ref3.note,
          note = _ref3$note === undefined ? '' : _ref3$note,
          _ref3$ruleId = _ref3.ruleId,
          ruleId = _ref3$ruleId === undefined ? '' : _ref3$ruleId;

      return new Promise(function (resolve, reject) {
        _this4.request().post('/groups', {
          productId: productId,
          note: note,
          ruleId: ruleId
        }).then(function (responses) {
          successLog('Create Group Success');
          resolve(responses);
        });
      });
    }
  }, {
    key: 'getRules',
    value: function getRules() {
      var _this5 = this;

      return new Promise(function (resolve, reject) {
        _this5.request().get('/rules').then(function (response) {
          successLog('Fetch rules success');
          resolve(response.data.payload);
        });
      });
    }
  }, {
    key: 'createRules',
    value: function createRules(_ref4) {
      var _this6 = this;

      var rules = _ref4.rules;

      return new Promise(function (resolve, reject) {
        _this6.request().post('/rules', {
          rules: rules
        }).then(function (responses) {
          successLog('Create Rules Success');
          resolve(responses);
        });
      });
    }
  }, {
    key: 'createOrder',
    value: function createOrder(_ref5) {
      var _this7 = this;

      var productId = _ref5.id,
          groupId = _ref5.groupId,
          buyers = _ref5.buyers,
          quantity = _ref5.quantity;

      return new Promise(function (resolve, reject) {
        _this7.request().post('/orders', {
          buyers: buyers,
          order: {
            quantity: quantity,
            productId: productId,
            groupId: groupId
          }
        }).then(function (response) {
          successLog('Create order success');
          resolve(response.data.payload.objectId);
        });
      });
      // Validate
      // 1. Five params should be exist if not return required hint
      // 2. Quantity should be number if not return format hint
      // 3. Make sure product is not expired
      // 4. Make sure group's quantity is enough or not
    }
  }, {
    key: 'getOrders',
    value: function getOrders() {
      var _this8 = this;

      return new Promise(function (resolve, reject) {
        _this8.request().get('/orders').then(function (response) {
          successLog('Fetch orders success');
          resolve(response.data.payload);
        });
      });
    }
  }, {
    key: 'createPayment',
    value: function createPayment(_ref6) {
      var _this9 = this;

      var orderId = _ref6.id,
          _ref6$next = _ref6.next,
          next = _ref6$next === undefined ? '' : _ref6$next;

      return new Promise(function (resolve, reject) {
        _this9.request().post('/orders/payment', {
          orderId: orderId,
          next: next
        }).then(function (response) {
          successLog('Create payment success');
          resolve(response.data.payload.order.payment.data.html);
        });
      });
    }
  }]);

  return LINA;
}();

module.exports = LINA;